{% load i18n %}
<div class="overflow">
    <table class="listing">
        <thead>
            <th>User</th>
            <th>IP</th>
            <th>Agent</th>
            <th>Actions</th>
        </thead>
        <tbody>
            {% for attempt in attempts %}
                <tr>
                    <td>{{ attempt.username }}</td>
                    <td>{{ attempt.ip_address }}</td>
                    <td>{{ attempt.user_agent }}</td>
                    <td><a href="{% url 'wagtailenforcer.views.axes.views.reset' attempt.id %}" class="button">{% trans "Unblock" %}</a></td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
</div>