{% extends "wagtailadmin/admin_base.html" %}
{% load staticfiles i18n %}
{% block titletag %}{% trans "Set your new password" %}{% endblock %}
{% block bodyclass %}login{% endblock %}

{% block extra_css %}
    {{ block.super }}

    <link rel="stylesheet" href="{% static 'wagtailadmin/css/layouts/login.css' %}" type="text/css" />
{% endblock %}

{% block furniture %}
    <div class="content-wrapper">
        <h1>{% trans "Too many login attempts" %}</h1>
        <div class="messages">
            <ul>
                <li class="error">{% trans "Your username has been lockout due to many failed login attempts. Please, contact with a site administrator." %}</li>
            </ul>
        </div>
    </div>
{% endblock %}