{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% blocktrans%}Attempts{% endblocktrans %}{% endblock %}
{% block bodyclass %}menu-forms{% endblock %}

{% block content %}
    <header class="nice-padding">
        <form action="" method="get">
            <div class="row">
                <div class="left">
                    <div class="col">
                        <h1 class="icon icon-locked">{% blocktrans%}Blocked Users{% endblocktrans %}</h1>
                    </div>
                </div>
                <div class="right">
                    <div class="col search-bar">
                        <ul class="fields row rowflush">
                            {% for field in search_form %}
                                {% include "wagtailadmin/shared/field_as_li.html" with field=field field_classes="field-small" li_classes="col6" %}
                            {% endfor %}
                            <li class="submit col3">
                                <input type="submit" class="button" value="{% trans 'Filter' %}">
                            </li>
                            <li class="submit col3">
                                <a href="{% url 'wagtailenforcer_blocked_users' %}" class="button">{% trans 'Reset' %}</a>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </form>
    </header>
    <div class="nice-padding">
        {% if attempts %}

            {% include "wagtailenforcer/list_attempts.html" %}

            {% include "wagtailenforcer/includes/pagination_nav.html" %}

        {% else %}
            <div class="messages">
                <ul>
                    <li class="warning">{% if is_searching %}{% trans 'No results for your search.' %}{% else %}{% trans 'No blocked users yet.' %}{% endif %}</li>
                </ul>
            </div>
        {% endif %}
    </div>
{% endblock %}